@@ -5,7 +5,6 @@ import (
 	"errors"
 	"fmt"
 	"io"
-	"io/ioutil" //nolint: staticcheck
 	"net/http"
 	"path/filepath"
 	"strconv"
@@ -16,14 +15,14 @@ import (
 
 	"github.com/maxatome/go-testdeep/td"
 
-	. "github.com/jarcoal/httpmock"
+	"github.com/jarcoal/httpmock"
 	"github.com/jarcoal/httpmock/internal"
 )
 
 func TestResponderFromResponse(t *testing.T) {
 	assert, require := td.AssertRequire(t)
 
-	responder := ResponderFromResponse(NewStringResponse(200, "hello world"))
+	responder := httpmock.ResponderFromResponse(httpmock.NewStringResponse(200, "hello world"))
 
 	req, err := http.NewRequest(http.MethodGet, testURL, nil)
 	require.CmpNoError(err)
@@ -53,13 +52,13 @@ func TestResponderFromResponse(t *testing.T) {
 func TestResponderFromResponses(t *testing.T) {
 	assert, require := td.AssertRequire(t)
 
-	jsonResponse, err := NewJsonResponse(200, map[string]string{"test": "toto"})
+	jsonResponse, err := httpmock.NewJsonResponse(200, map[string]string{"test": "toto"})
 	require.CmpNoError(err)
 
-	responder := ResponderFromMultipleResponses(
+	responder := httpmock.ResponderFromMultipleResponses(
 		[]*http.Response{
 			jsonResponse,
-			NewStringResponse(200, "hello world"),
+			httpmock.NewStringResponse(200, "hello world"),
 		},
 	)
 
@@ -92,7 +91,7 @@ func TestResponderFromResponses(t *testing.T) {
 	assert.String(err, "not enough responses provided: responder called 3 time(s) but 2 response(s) provided")
 
 	// fn usage
-	responder = ResponderFromMultipleResponses([]*http.Response{}, func(args ...interface{}) {})
+	responder = httpmock.ResponderFromMultipleResponses([]*http.Response{}, func(args ...interface{}) {})
 	_, err = responder(req)
 	assert.String(err, "not enough responses provided: responder called 1 time(s) but 0 response(s) provided")
 	if assert.Isa(err, internal.StackTracer{}) {
@@ -103,7 +102,7 @@ func TestResponderFromResponses(t *testing.T) {
 func TestNewNotFoundResponder(t *testing.T) {
 	assert, require := td.AssertRequire(t)
 
-	responder := NewNotFoundResponder(func(args ...interface{}) {})
+	responder := httpmock.NewNotFoundResponder(func(args ...interface{}) {})
 
 	req, err := http.NewRequest("GET", "http://foo.bar/path", nil)
 	require.CmpNoError(err)
@@ -118,7 +117,7 @@ func TestNewNotFoundResponder(t *testing.T) {
 	}
 
 	// nil fn
-	responder = NewNotFoundResponder(nil)
+	responder = httpmock.NewNotFoundResponder(nil)
 
 	resp, err = responder(req)
 	assert.Nil(resp)
@@ -135,9 +134,9 @@ func TestNewStringResponse(t *testing.T) {
 		body   = "hello world"
 		status = 200
 	)
-	response := NewStringResponse(status, body)
+	response := httpmock.NewStringResponse(status, body)
 
-	data, err := ioutil.ReadAll(response.Body)
+	data, err := io.ReadAll(response.Body)
 	require.CmpNoError(err)
 
 	assert.String(data, body)
@@ -151,9 +150,9 @@ func TestNewBytesResponse(t *testing.T) {
 		body   = "hello world"
 		status = 200
 	)
-	response := NewBytesResponse(status, []byte(body))
+	response := httpmock.NewBytesResponse(status, []byte(body))
 
-	data, err := ioutil.ReadAll(response.Body)
+	data, err := io.ReadAll(response.Body)
 	require.CmpNoError(err)
 
 	assert.String(data, body)
@@ -167,8 +166,7 @@ func TestNewJsonResponse(t *testing.T) {
 		Hello string `json:"hello"`
 	}
 
-	dir, cleanup := tmpDir(assert)
-	defer cleanup()
+	dir := assert.TempDir()
 	fileName := filepath.Join(dir, "ok.json")
 	writeFile(assert, fileName, []byte(`{ "test": true }`))
 
@@ -177,10 +175,10 @@ func TestNewJsonResponse(t *testing.T) {
 		expected string
 	}{
 		{body: &schema{"world"}, expected: `{"hello":"world"}`},
-		{body: File(fileName), expected: `{"test":true}`},
+		{body: httpmock.File(fileName), expected: `{"test":true}`},
 	} {
 		assert.Run(fmt.Sprintf("#%d", i), func(assert *td.T) {
-			response, err := NewJsonResponse(200, test.body)
+			response, err := httpmock.NewJsonResponse(200, test.body)
 			if !assert.CmpNoError(err) {
 				return
 			}
@@ -191,12 +189,46 @@ func TestNewJsonResponse(t *testing.T) {
 	}
 
 	// Error case
-	response, err := NewJsonResponse(200, func() {})
+	response, err := httpmock.NewJsonResponse(200, func() {})
 	assert.CmpError(err)
 	assert.Nil(response)
 }
 
-func checkResponder(assert *td.T, r Responder, expectedStatus int, expectedBody string) {
+func TestNewJsonResponseOrPanic(t *testing.T) {
+	assert := td.Assert(t)
+
+	type schema struct {
+		Hello string `json:"hello"`
+	}
+
+	dir := assert.TempDir()
+	fileName := filepath.Join(dir, "ok.json")
+	writeFile(assert, fileName, []byte(`{ "test": true }`))
+
+	for i, test := range []struct {
+		body     interface{}
+		expected string
+	}{
+		{body: &schema{"world"}, expected: `{"hello":"world"}`},
+		{body: httpmock.File(fileName), expected: `{"test":true}`},
+	} {
+		assert.Run(fmt.Sprintf("#%d", i), func(assert *td.T) {
+			assert.CmpNotPanic(func() {
+				response := httpmock.NewJsonResponseOrPanic(200, test.body)
+				assert.Cmp(response.StatusCode, 200)
+				assert.Cmp(response.Header.Get("Content-Type"), "application/json")
+				assertBody(assert, response, test.expected)
+			})
+		})
+	}
+
+	// Error case
+	assert.CmpPanic(
+		func() { httpmock.NewJsonResponseOrPanic(200, func() {}) },
+		td.Contains("json: unsupported type"))
+}
+
+func checkResponder(assert *td.T, r httpmock.Responder, expectedStatus int, expectedBody string) {
 	assert.Helper()
 
 	req, err := http.NewRequest(http.MethodGet, "/foo", nil)
@@ -219,26 +251,25 @@ func TestNewJsonResponder(t *testing.T) {
 	assert := td.Assert(t)
 
 	assert.Run("OK", func(assert *td.T) {
-		r, err := NewJsonResponder(200, map[string]int{"foo": 42})
+		r, err := httpmock.NewJsonResponder(200, map[string]int{"foo": 42})
 		if assert.CmpNoError(err) {
 			checkResponder(assert, r, 200, `{"foo":42}`)
 		}
 	})
 
 	assert.Run("OK file", func(assert *td.T) {
-		dir, cleanup := tmpDir(assert)
-		defer cleanup()
+		dir := assert.TempDir()
 		fileName := filepath.Join(dir, "ok.json")
 		writeFile(assert, fileName, []byte(`{  "foo"  :  42  }`))
 
-		r, err := NewJsonResponder(200, File(fileName))
+		r, err := httpmock.NewJsonResponder(200, httpmock.File(fileName))
 		if assert.CmpNoError(err) {
 			checkResponder(assert, r, 200, `{"foo":42}`)
 		}
 	})
 
 	assert.Run("Error", func(assert *td.T) {
-		r, err := NewJsonResponder(200, func() {})
+		r, err := httpmock.NewJsonResponder(200, func() {})
 		assert.CmpError(err)
 		assert.Nil(r)
 	})
@@ -246,14 +277,14 @@ func TestNewJsonResponder(t *testing.T) {
 	assert.Run("OK don't panic", func(assert *td.T) {
 		assert.CmpNotPanic(
 			func() {
-				r := NewJsonResponderOrPanic(200, map[string]int{"foo": 42})
+				r := httpmock.NewJsonResponderOrPanic(200, map[string]int{"foo": 42})
 				checkResponder(assert, r, 200, `{"foo":42}`)
 			})
 	})
 
 	assert.Run("Panic", func(assert *td.T) {
 		assert.CmpPanic(
-			func() { NewJsonResponderOrPanic(200, func() {}) },
+			func() { httpmock.NewJsonResponderOrPanic(200, func() {}) },
 			td.Ignore())
 	})
 }
@@ -273,8 +304,7 @@ func TestNewXmlResponse(t *testing.T) {
 	}
 	expectedBody := string(b)
 
-	dir, cleanup := tmpDir(assert)
-	defer cleanup()
+	dir := assert.TempDir()
 	fileName := filepath.Join(dir, "ok.xml")
 	writeFile(assert, fileName, b)
 
@@ -283,10 +313,10 @@ func TestNewXmlResponse(t *testing.T) {
 		expected string
 	}{
 		{body: body, expected: expectedBody},
-		{body: File(fileName), expected: expectedBody},
+		{body: httpmock.File(fileName), expected: expectedBody},
 	} {
 		assert.Run(fmt.Sprintf("#%d", i), func(assert *td.T) {
-			response, err := NewXmlResponse(200, test.body)
+			response, err := httpmock.NewXmlResponse(200, test.body)
 			if !assert.CmpNoError(err) {
 				return
 			}
@@ -297,7 +327,7 @@ func TestNewXmlResponse(t *testing.T) {
 	}
 
 	// Error case
-	response, err := NewXmlResponse(200, func() {})
+	response, err := httpmock.NewXmlResponse(200, func() {})
 	assert.CmpError(err)
 	assert.Nil(response)
 }
@@ -312,26 +342,25 @@ func TestNewXmlResponder(t *testing.T) {
 	expectedBody := string(b)
 
 	assert.Run("OK", func(assert *td.T) {
-		r, err := NewXmlResponder(200, body)
+		r, err := httpmock.NewXmlResponder(200, body)
 		if assert.CmpNoError(err) {
 			checkResponder(assert, r, 200, expectedBody)
 		}
 	})
 
 	assert.Run("OK file", func(assert *td.T) {
-		dir, cleanup := tmpDir(assert)
-		defer cleanup()
+		dir := assert.TempDir()
 		fileName := filepath.Join(dir, "ok.xml")
 		writeFile(assert, fileName, b)
 
-		r, err := NewXmlResponder(200, File(fileName))
+		r, err := httpmock.NewXmlResponder(200, httpmock.File(fileName))
 		if assert.CmpNoError(err) {
 			checkResponder(assert, r, 200, expectedBody)
 		}
 	})
 
 	assert.Run("Error", func(assert *td.T) {
-		r, err := NewXmlResponder(200, func() {})
+		r, err := httpmock.NewXmlResponder(200, func() {})
 		assert.CmpError(err)
 		assert.Nil(r)
 	})
@@ -339,14 +368,14 @@ func TestNewXmlResponder(t *testing.T) {
 	assert.Run("OK don't panic", func(assert *td.T) {
 		assert.CmpNotPanic(
 			func() {
-				r := NewXmlResponderOrPanic(200, body)
+				r := httpmock.NewXmlResponderOrPanic(200, body)
 				checkResponder(assert, r, 200, expectedBody)
 			})
 	})
 
 	assert.Run("Panic", func(assert *td.T) {
 		assert.CmpPanic(
-			func() { NewXmlResponderOrPanic(200, func() {}) },
+			func() { httpmock.NewXmlResponderOrPanic(200, func() {}) },
 			td.Ignore())
 	})
 }
@@ -355,7 +384,7 @@ func TestNewErrorResponder(t *testing.T) {
 	assert, require := td.AssertRequire(t)
 
 	origError := errors.New("oh no")
-	responder := NewErrorResponder(origError)
+	responder := httpmock.NewErrorResponder(origError)
 
 	req, err := http.NewRequest(http.MethodGet, testURL, nil)
 	require.CmpNoError(err)
@@ -375,8 +404,8 @@ func TestResponseBody(t *testing.T) {
 
 	assert.Run("http.Response", func(assert *td.T) {
 		for i, response := range []*http.Response{
-			NewBytesResponse(status, []byte(body)),
-			NewStringResponse(status, body),
+			httpmock.NewBytesResponse(status, []byte(body)),
+			httpmock.NewStringResponse(status, body),
 		} {
 			assert.Run(fmt.Sprintf("resp #%d", i), func(assert *td.T) {
 				assertBody(assert, response, body)
@@ -391,9 +420,9 @@ func TestResponseBody(t *testing.T) {
 	})
 
 	assert.Run("Responder", func(assert *td.T) {
-		for i, responder := range []Responder{
-			NewBytesResponder(200, []byte(body)),
-			NewStringResponder(200, body),
+		for i, responder := range []httpmock.Responder{
+			httpmock.NewBytesResponder(200, []byte(body)),
+			httpmock.NewStringResponder(200, body),
 		} {
 			assert.Run(fmt.Sprintf("resp #%d", i), func(assert *td.T) {
 				req, _ := http.NewRequest("GET", "http://foo.bar", nil)
@@ -418,7 +447,7 @@ func TestResponder(t *testing.T) {
 
 	resp := &http.Response{}
 
-	chk := func(r Responder, expectedResp *http.Response, expectedErr string) {
+	chk := func(r httpmock.Responder, expectedResp *http.Response, expectedErr string) {
 		t.Helper()
 		gotResp, gotErr := r(req)
 		td.CmpShallow(t, gotResp, expectedResp)
@@ -444,7 +473,7 @@ func TestResponder(t *testing.T) {
 		called = false
 	}
 
-	r := Responder(func(*http.Request) (*http.Response, error) {
+	r := httpmock.Responder(func(*http.Request) (*http.Response, error) {
 		called = true
 		return resp, nil
 	})
@@ -520,20 +549,20 @@ func TestResponder_Then(t *testing.T) {
 	//
 	// Then
 	var stack string
-	newResponder := func(level string) Responder {
+	newResponder := func(level string) httpmock.Responder {
 		return func(*http.Request) (*http.Response, error) {
 			stack += level
-			return NewStringResponse(200, level), nil
+			return httpmock.NewStringResponse(200, level), nil
 		}
 	}
-	var rt Responder
+	var rt httpmock.Responder
 	chk := func(assert *td.T, expectedLevel, expectedStack string) {
 		assert.Helper()
 		resp, err := rt(req)
 		if !assert.CmpNoError(err, "Responder call") {
 			return
 		}
-		b, err := ioutil.ReadAll(resp.Body)
+		b, err := io.ReadAll(resp.Body)
 		if !assert.CmpNoError(err, "Read response") {
 			return
 		}
@@ -595,12 +624,12 @@ func TestResponder_SetContentLength(t *testing.T) {
 
 	testCases := []struct {
 		name   string
-		r      Responder
+		r      httpmock.Responder
 		expLen int
 	}{
 		{
 			name: "nil body",
-			r: ResponderFromResponse(&http.Response{
+			r: httpmock.ResponderFromResponse(&http.Response{
 				StatusCode:    200,
 				ContentLength: -1,
 			}),
@@ -608,7 +637,7 @@ func TestResponder_SetContentLength(t *testing.T) {
 		},
 		{
 			name: "http.NoBody",
-			r: ResponderFromResponse(&http.Response{
+			r: httpmock.ResponderFromResponse(&http.Response{
 				Body:          http.NoBody,
 				StatusCode:    200,
 				ContentLength: -1,
@@ -617,18 +646,18 @@ func TestResponder_SetContentLength(t *testing.T) {
 		},
 		{
 			name:   "string",
-			r:      NewStringResponder(200, "BODY"),
+			r:      httpmock.NewStringResponder(200, "BODY"),
 			expLen: 4,
 		},
 		{
 			name:   "bytes",
-			r:      NewBytesResponder(200, []byte("BODY")),
+			r:      httpmock.NewBytesResponder(200, []byte("BODY")),
 			expLen: 4,
 		},
 		{
 			name: "from response OK",
-			r: ResponderFromResponse(&http.Response{
-				Body:          NewRespBodyFromString("BODY"),
+			r: httpmock.ResponderFromResponse(&http.Response{
+				Body:          httpmock.NewRespBodyFromString("BODY"),
 				StatusCode:    200,
 				ContentLength: -1,
 			}),
@@ -638,7 +667,7 @@ func TestResponder_SetContentLength(t *testing.T) {
 			name: "custom without Len",
 			r: func(req *http.Request) (*http.Response, error) {
 				return &http.Response{
-					Body:          ioutil.NopCloser(strings.NewReader("BODY")),
+					Body:          io.NopCloser(strings.NewReader("BODY")),
 					StatusCode:    200,
 					ContentLength: -1,
 				}, nil
@@ -662,7 +691,7 @@ func TestResponder_SetContentLength(t *testing.T) {
 	}
 
 	assert.Run("error", func(assert *td.T) {
-		resp, err := NewErrorResponder(errors.New("an error occurred")).
+		resp, err := httpmock.NewErrorResponder(errors.New("an error occurred")).
 			SetContentLength()(req)
 		assert.Nil(resp)
 		assert.String(err, "an error occurred")
@@ -675,11 +704,11 @@ func TestResponder_HeaderAddSet(t *testing.T) {
 	req, err := http.NewRequest(http.MethodGet, "http://foo.bar", nil)
 	require.CmpNoError(err)
 
-	orig := NewStringResponder(200, "body")
-	origNilHeader := ResponderFromResponse(&http.Response{
-		Status:        "200",
+	orig := httpmock.NewStringResponder(200, "body")
+	origNilHeader := httpmock.ResponderFromResponse(&http.Response{
+		Status:        "200 OK",
 		StatusCode:    200,
-		Body:          NewRespBodyFromString("body"),
+		Body:          httpmock.NewRespBodyFromString("body"),
 		ContentLength: -1,
 	})
 
@@ -688,7 +717,7 @@ func TestResponder_HeaderAddSet(t *testing.T) {
 
 	testCases := []struct {
 		name string
-		orig Responder
+		orig httpmock.Responder
 	}{
 		{name: "orig", orig: orig},
 		{name: "nil header", orig: origNilHeader},
@@ -734,7 +763,7 @@ func TestResponder_HeaderAddSet(t *testing.T) {
 	})
 
 	assert.Run("error", func(assert *td.T) {
-		origErr := NewErrorResponder(errors.New("an error occurred"))
+		origErr := httpmock.NewErrorResponder(errors.New("an error occurred"))
 
 		assert.Run("HeaderAdd", func(assert *td.T) {
 			r := origErr.HeaderAdd(http.Header{"foo": {"bar"}})
@@ -758,9 +787,9 @@ func TestParallelResponder(t *testing.T) {
 
 	body := strings.Repeat("ABC-", 1000)
 
-	for ir, r := range []Responder{
-		NewStringResponder(200, body),
-		NewBytesResponder(200, []byte(body)),
+	for ir, r := range []httpmock.Responder{
+		httpmock.NewStringResponder(200, body),
+		httpmock.NewBytesResponder(200, []byte(body)),
 	} {
 		var wg sync.WaitGroup
 		for n := 0; n < 100; n++ {
@@ -768,7 +797,7 @@ func TestParallelResponder(t *testing.T) {
 			go func() {
 				defer wg.Done()
 				resp, _ := r(req)
-				b, err := ioutil.ReadAll(resp.Body)
+				b, err := io.ReadAll(resp.Body)
 				td.CmpNoError(t, err, "resp #%d", ir)
 				td.CmpLen(t, b, 4000, "resp #%d", ir)
 				td.CmpHasPrefix(t, b, "ABC-", "resp #%d", ir)
